aboutsummaryrefslogtreecommitdiffstats
path: root/src/mds-kbdc/simplify-tree.h
diff options
context:
space:
mode:
authorMattias Andrée <maandree@operamail.com>2014-11-22 12:10:37 +0100
committerMattias Andrée <maandree@operamail.com>2014-11-22 12:11:33 +0100
commitd367918916baf9290816aa8657cc78878b68c1ef (patch)
treedddf55ae25b4d3c00be3b49f86f4c3e32276f6ab /src/mds-kbdc/simplify-tree.h
parentm work on smplification (diff)
downloadmds-d367918916baf9290816aa8657cc78878b68c1ef.tar.gz
mds-d367918916baf9290816aa8657cc78878b68c1ef.tar.bz2
mds-d367918916baf9290816aa8657cc78878b68c1ef.tar.xz
Starting on some rework
Signed-off-by: Mattias Andrée <maandree@operamail.com>
Diffstat (limited to '')
-rw-r--r--src/mds-kbdc/simplify-tree.h10
1 files changed, 6 insertions, 4 deletions
diff --git a/src/mds-kbdc/simplify-tree.h b/src/mds-kbdc/simplify-tree.h
index c45f1de..94e4f94 100644
--- a/src/mds-kbdc/simplify-tree.h
+++ b/src/mds-kbdc/simplify-tree.h
@@ -26,11 +26,13 @@
/**
* Simplify a tree and generate related warnings in the process
*
* @param tree The tree, it may be modified
* @param errors `NULL`-terminated list of found error, `NULL` if no errors were found or if -1 is returned
* @return -1 if an error occursed that cannot be stored in `*errors`, zero otherwise
*/
-int simplify_tree(mds_kbdc_tree_t* restrict tree, mds_kbdc_parse_error_t*** restrict errors);
+int simplify_tree(const char* restrict filename, mds_kbdc_tree_t* restrict tree,
+ mds_kbdc_parse_error_t*** restrict errors);
#endif
@@ -26,11 +26,13 @@
* Simplify a tree and generate related warnings in the process
*
- * @param tree The tree, it may be modified
- * @param errors `NULL`-terminated list of found error, `NULL` if no errors were found or if -1 is returned
- * @return -1 if an error occursed that cannot be stored in `*errors`, zero otherwise
+ * @param filename The filename of the tree that have been parsed
+ * @param tree The tree, it may be modified
+ * @param errors `NULL`-terminated list of found error, `NULL` if no errors were found or if -1 is returned
+ * @return -1 if an error occursed that cannot be stored in `*errors`, zero otherwise
*/